@@ -10,17 +10,27 @@ import pandas.util._test_decorators as td
 from pandas.core.dtypes.common import is_integer_dtype
 
 import pandas as pd
-from pandas import Series, isna
+from pandas import (
+    Series,
+    isna,
+)
 import pandas._testing as tm
 from pandas.core.arrays import DatetimeArray
 import pandas.core.nanops as nanops
 
 use_bn = nanops._USE_BOTTLENECK
-has_c16 = hasattr(np, "complex128")
+
+
+@pytest.fixture(params=[True, False])
+def skipna(request):
+    """
+    Fixture to pass skipna to nanops functions.
+    """
+    return request.param
 
 
 class TestnanopsDataFrame:
-    def setup_method(self, method):
+    def setup_method(self):
         np.random.seed(11235)
         nanops._USE_BOTTLENECK = False
 
@@ -84,33 +94,19 @@ class TestnanopsDataFrame:
         self.arr_float1_nan_1d = self.arr_float1_nan[:, 0]
         self.arr_nan_float1_1d = self.arr_nan_float1[:, 0]
 
-    def teardown_method(self, method):
+    def teardown_method(self):
         nanops._USE_BOTTLENECK = use_bn
 
     def check_results(self, targ, res, axis, check_dtype=True):
         res = getattr(res, "asm8", res)
-        res = getattr(res, "values", res)
 
-        # timedeltas are a beast here
-        def _coerce_tds(targ, res):
-            if hasattr(targ, "dtype") and targ.dtype == "m8[ns]":
-                if len(targ) == 1:
-                    targ = targ[0].item()
-                    res = res.item()
-                else:
-                    targ = targ.view("i8")
-            return targ, res
-
-        try:
-            if (
-                axis != 0
-                and hasattr(targ, "shape")
-                and targ.ndim
-                and targ.shape != res.shape
-            ):
-                res = np.split(res, [targ.shape[0]], axis=0)[0]
-        except (ValueError, IndexError):
-            targ, res = _coerce_tds(targ, res)
+        if (
+            axis != 0
+            and hasattr(targ, "shape")
+            and targ.ndim
+            and targ.shape != res.shape
+        ):
+            res = np.split(res, [targ.shape[0]], axis=0)[0]
 
         try:
             tm.assert_almost_equal(targ, res, check_dtype=check_dtype)
@@ -118,9 +114,7 @@ class TestnanopsDataFrame:
 
             # handle timedelta dtypes
             if hasattr(targ, "dtype") and targ.dtype == "m8[ns]":
-                targ, res = _coerce_tds(targ, res)
-                tm.assert_almost_equal(targ, res, check_dtype=check_dtype)
-                return
+                raise
 
             # There are sometimes rounding errors with
             # complex and object dtypes.
@@ -133,7 +127,7 @@ class TestnanopsDataFrame:
                 if targ.dtype.kind != "O":
                     res = res.astype(targ.dtype)
                 else:
-                    cast_dtype = "c16" if has_c16 else "f8"
+                    cast_dtype = "c16" if hasattr(np, "complex128") else "f8"
                     res = res.astype(cast_dtype)
                     targ = targ.astype(cast_dtype)
             # there should never be a case where numpy returns an object
@@ -149,29 +143,38 @@ class TestnanopsDataFrame:
         targfunc,
         testarval,
         targarval,
+        skipna,
         check_dtype=True,
         empty_targfunc=None,
         **kwargs,
     ):
         for axis in list(range(targarval.ndim)) + [None]:
-            for skipna in [False, True]:
-                targartempval = targarval if skipna else testarval
-                if skipna and empty_targfunc and isna(targartempval).all():
-                    targ = empty_targfunc(targartempval, axis=axis, **kwargs)
-                else:
-                    targ = targfunc(targartempval, axis=axis, **kwargs)
+            targartempval = targarval if skipna else testarval
+            if skipna and empty_targfunc and isna(targartempval).all():
+                targ = empty_targfunc(targartempval, axis=axis, **kwargs)
+            else:
+                targ = targfunc(targartempval, axis=axis, **kwargs)
 
-                res = testfunc(testarval, axis=axis, skipna=skipna, **kwargs)
+            if targartempval.dtype == object and (
+                targfunc is np.any or targfunc is np.all
+            ):
+                # GH#12863 the numpy functions will retain e.g. floatiness
+                if isinstance(targ, np.ndarray):
+                    targ = targ.astype(bool)
+                else:
+                    targ = bool(targ)
+
+            res = testfunc(testarval, axis=axis, skipna=skipna, **kwargs)
+            self.check_results(targ, res, axis, check_dtype=check_dtype)
+            if skipna:
+                res = testfunc(testarval, axis=axis, **kwargs)
+                self.check_results(targ, res, axis, check_dtype=check_dtype)
+            if axis is None:
+                res = testfunc(testarval, skipna=skipna, **kwargs)
+                self.check_results(targ, res, axis, check_dtype=check_dtype)
+            if skipna and axis is None:
+                res = testfunc(testarval, **kwargs)
                 self.check_results(targ, res, axis, check_dtype=check_dtype)
-                if skipna:
-                    res = testfunc(testarval, axis=axis, **kwargs)
-                    self.check_results(targ, res, axis, check_dtype=check_dtype)
-                if axis is None:
-                    res = testfunc(testarval, skipna=skipna, **kwargs)
-                    self.check_results(targ, res, axis, check_dtype=check_dtype)
-                if skipna and axis is None:
-                    res = testfunc(testarval, **kwargs)
-                    self.check_results(targ, res, axis, check_dtype=check_dtype)
 
         if testarval.ndim <= 1:
             return
@@ -184,12 +187,15 @@ class TestnanopsDataFrame:
             targfunc,
             testarval2,
             targarval2,
+            skipna=skipna,
             check_dtype=check_dtype,
             empty_targfunc=empty_targfunc,
             **kwargs,
         )
 
-    def check_fun(self, testfunc, targfunc, testar, empty_targfunc=None, **kwargs):
+    def check_fun(
+        self, testfunc, targfunc, testar, skipna, empty_targfunc=None, **kwargs
+    ):
 
         targar = testar
         if testar.endswith("_nan") and hasattr(self, testar[:-4]):
@@ -202,6 +208,7 @@ class TestnanopsDataFrame:
             targfunc,
             testarval,
             targarval,
+            skipna=skipna,
             empty_targfunc=empty_targfunc,
             **kwargs,
         )
@@ -210,6 +217,7 @@ class TestnanopsDataFrame:
         self,
         testfunc,
         targfunc,
+        skipna,
         allow_complex=True,
         allow_all_nan=True,
         allow_date=True,
@@ -217,10 +225,10 @@ class TestnanopsDataFrame:
         allow_obj=True,
         **kwargs,
     ):
-        self.check_fun(testfunc, targfunc, "arr_float", **kwargs)
-        self.check_fun(testfunc, targfunc, "arr_float_nan", **kwargs)
-        self.check_fun(testfunc, targfunc, "arr_int", **kwargs)
-        self.check_fun(testfunc, targfunc, "arr_bool", **kwargs)
+        self.check_fun(testfunc, targfunc, "arr_float", skipna, **kwargs)
+        self.check_fun(testfunc, targfunc, "arr_float_nan", skipna, **kwargs)
+        self.check_fun(testfunc, targfunc, "arr_int", skipna, **kwargs)
+        self.check_fun(testfunc, targfunc, "arr_bool", skipna, **kwargs)
         objs = [
             self.arr_float.astype("O"),
             self.arr_int.astype("O"),
@@ -228,18 +236,18 @@ class TestnanopsDataFrame:
         ]
 
         if allow_all_nan:
-            self.check_fun(testfunc, targfunc, "arr_nan", **kwargs)
+            self.check_fun(testfunc, targfunc, "arr_nan", skipna, **kwargs)
 
         if allow_complex:
-            self.check_fun(testfunc, targfunc, "arr_complex", **kwargs)
-            self.check_fun(testfunc, targfunc, "arr_complex_nan", **kwargs)
+            self.check_fun(testfunc, targfunc, "arr_complex", skipna, **kwargs)
+            self.check_fun(testfunc, targfunc, "arr_complex_nan", skipna, **kwargs)
             if allow_all_nan:
-                self.check_fun(testfunc, targfunc, "arr_nan_nanj", **kwargs)
+                self.check_fun(testfunc, targfunc, "arr_nan_nanj", skipna, **kwargs)
             objs += [self.arr_complex.astype("O")]
 
         if allow_date:
             targfunc(self.arr_date)
-            self.check_fun(testfunc, targfunc, "arr_date", **kwargs)
+            self.check_fun(testfunc, targfunc, "arr_date", skipna, **kwargs)
             objs += [self.arr_date.astype("O")]
 
         if allow_tdelta:
@@ -248,7 +256,7 @@ class TestnanopsDataFrame:
             except TypeError:
                 pass
             else:
-                self.check_fun(testfunc, targfunc, "arr_tdelta", **kwargs)
+                self.check_fun(testfunc, targfunc, "arr_tdelta", skipna, **kwargs)
                 objs += [self.arr_tdelta.astype("O")]
 
         if allow_obj:
@@ -260,7 +268,7 @@ class TestnanopsDataFrame:
                 targfunc = partial(
                     self._badobj_wrap, func=targfunc, allow_complex=allow_complex
                 )
-            self.check_fun(testfunc, targfunc, "arr_obj", **kwargs)
+            self.check_fun(testfunc, targfunc, "arr_obj", skipna, **kwargs)
 
     def _badobj_wrap(self, value, func, allow_complex=True, **kwargs):
         if value.dtype.kind == "O":
@@ -273,28 +281,22 @@ class TestnanopsDataFrame:
     @pytest.mark.parametrize(
         "nan_op,np_op", [(nanops.nanany, np.any), (nanops.nanall, np.all)]
     )
-    def test_nan_funcs(self, nan_op, np_op):
-        # TODO: allow tdelta, doesn't break tests
-        self.check_funs(
-            nan_op, np_op, allow_all_nan=False, allow_date=False, allow_tdelta=False
-        )
+    def test_nan_funcs(self, nan_op, np_op, skipna):
+        self.check_funs(nan_op, np_op, skipna, allow_all_nan=False, allow_date=False)
 
-    def test_nansum(self):
+    def test_nansum(self, skipna):
         self.check_funs(
             nanops.nansum,
             np.sum,
+            skipna,
             allow_date=False,
             check_dtype=False,
             empty_targfunc=np.nansum,
         )
 
-    def test_nanmean(self):
+    def test_nanmean(self, skipna):
         self.check_funs(
-            nanops.nanmean,
-            np.mean,
-            allow_complex=False,  # TODO: allow this, doesn't break test
-            allow_obj=False,
-            allow_date=False,
+            nanops.nanmean, np.mean, skipna, allow_obj=False, allow_date=False
         )
 
     def test_nanmean_overflow(self):
@@ -302,7 +304,7 @@ class TestnanopsDataFrame:
         # In the previous implementation mean can overflow for int dtypes, it
         # is now consistent with numpy
 
-        for a in [2 ** 55, -(2 ** 55), 20150515061816532]:
+        for a in [2**55, -(2**55), 20150515061816532]:
             s = Series(a, index=range(500), dtype=np.int64)
             result = s.mean()
             np_result = s.values.mean()
@@ -336,22 +338,24 @@ class TestnanopsDataFrame:
             else:
                 assert result.dtype == dtype
 
-    def test_nanmedian(self):
+    def test_nanmedian(self, skipna):
         with warnings.catch_warnings(record=True):
             warnings.simplefilter("ignore", RuntimeWarning)
             self.check_funs(
                 nanops.nanmedian,
                 np.median,
+                skipna,
                 allow_complex=False,
                 allow_date=False,
                 allow_obj="convert",
             )
 
     @pytest.mark.parametrize("ddof", range(3))
-    def test_nanvar(self, ddof):
+    def test_nanvar(self, ddof, skipna):
         self.check_funs(
             nanops.nanvar,
             np.var,
+            skipna,
             allow_complex=False,
             allow_date=False,
             allow_obj="convert",
@@ -359,10 +363,11 @@ class TestnanopsDataFrame:
         )
 
     @pytest.mark.parametrize("ddof", range(3))
-    def test_nanstd(self, ddof):
+    def test_nanstd(self, ddof, skipna):
         self.check_funs(
             nanops.nanstd,
             np.std,
+            skipna,
             allow_complex=False,
             allow_date=False,
             allow_obj="convert",
@@ -371,13 +376,14 @@ class TestnanopsDataFrame:
 
     @td.skip_if_no_scipy
     @pytest.mark.parametrize("ddof", range(3))
-    def test_nansem(self, ddof):
+    def test_nansem(self, ddof, skipna):
         from scipy.stats import sem
 
         with np.errstate(invalid="ignore"):
             self.check_funs(
                 nanops.nansem,
                 sem,
+                skipna,
                 allow_complex=False,
                 allow_date=False,
                 allow_tdelta=False,
@@ -388,10 +394,10 @@ class TestnanopsDataFrame:
     @pytest.mark.parametrize(
         "nan_op,np_op", [(nanops.nanmin, np.min), (nanops.nanmax, np.max)]
     )
-    def test_nanops_with_warnings(self, nan_op, np_op):
+    def test_nanops_with_warnings(self, nan_op, np_op, skipna):
         with warnings.catch_warnings(record=True):
             warnings.simplefilter("ignore", RuntimeWarning)
-            self.check_funs(nan_op, np_op, allow_obj=False)
+            self.check_funs(nan_op, np_op, skipna, allow_obj=False)
 
     def _argminmax_wrap(self, value, axis=None, func=None):
         res = func(value, axis)
@@ -408,17 +414,17 @@ class TestnanopsDataFrame:
             res = -1
         return res
 
-    def test_nanargmax(self):
+    def test_nanargmax(self, skipna):
         with warnings.catch_warnings(record=True):
             warnings.simplefilter("ignore", RuntimeWarning)
             func = partial(self._argminmax_wrap, func=np.argmax)
-            self.check_funs(nanops.nanargmax, func, allow_obj=False)
+            self.check_funs(nanops.nanargmax, func, skipna, allow_obj=False)
 
-    def test_nanargmin(self):
+    def test_nanargmin(self, skipna):
         with warnings.catch_warnings(record=True):
             warnings.simplefilter("ignore", RuntimeWarning)
             func = partial(self._argminmax_wrap, func=np.argmin)
-            self.check_funs(nanops.nanargmin, func, allow_obj=False)
+            self.check_funs(nanops.nanargmin, func, skipna, allow_obj=False)
 
     def _skew_kurt_wrap(self, values, axis=None, func=None):
         if not isinstance(values.dtype.type, np.floating):
@@ -433,7 +439,7 @@ class TestnanopsDataFrame:
         return result
 
     @td.skip_if_no_scipy
-    def test_nanskew(self):
+    def test_nanskew(self, skipna):
         from scipy.stats import skew
 
         func = partial(self._skew_kurt_wrap, func=skew)
@@ -441,13 +447,14 @@ class TestnanopsDataFrame:
             self.check_funs(
                 nanops.nanskew,
                 func,
+                skipna,
                 allow_complex=False,
                 allow_date=False,
                 allow_tdelta=False,
             )
 
     @td.skip_if_no_scipy
-    def test_nankurt(self):
+    def test_nankurt(self, skipna):
         from scipy.stats import kurtosis
 
         func1 = partial(kurtosis, fisher=True)
@@ -456,15 +463,17 @@ class TestnanopsDataFrame:
             self.check_funs(
                 nanops.nankurt,
                 func,
+                skipna,
                 allow_complex=False,
                 allow_date=False,
                 allow_tdelta=False,
             )
 
-    def test_nanprod(self):
+    def test_nanprod(self, skipna):
         self.check_funs(
             nanops.nanprod,
             np.prod,
+            skipna,
             allow_date=False,
             allow_tdelta=False,
             empty_targfunc=np.nanprod,
@@ -602,7 +611,7 @@ class TestnanopsDataFrame:
     def test_invalid_method(self):
         targ0 = np.corrcoef(self.arr_float_2d, self.arr_float1_2d)[0, 1]
         targ1 = np.corrcoef(self.arr_float_2d.flat, self.arr_float1_2d.flat)[0, 1]
-        msg = "Unkown method 'foo', expected one of 'kendall', 'spearman'"
+        msg = "Unknown method 'foo', expected one of 'kendall', 'spearman'"
         with pytest.raises(ValueError, match=msg):
             self.check_nancorr_nancov_1d(nanops.nancorr, targ0, targ1, method="foo")
 
@@ -750,8 +759,8 @@ class TestEnsureNumeric:
 
         # Test non-convertible string ndarray
         s_values = np.array(["foo", "bar", "baz"], dtype=object)
-        msg = r"could not convert string to float: '(foo|baz)'"
-        with pytest.raises(ValueError, match=msg):
+        msg = r"Could not convert .* to numeric"
+        with pytest.raises(TypeError, match=msg):
             nanops._ensure_numeric(s_values)
 
     def test_convertable_values(self):
@@ -776,35 +785,35 @@ class TestNanvarFixedValues:
 
     # xref GH10242
 
-    def setup_method(self, method):
+    def setup_method(self):
         # Samples from a normal distribution.
         self.variance = variance = 3.0
-        self.samples = self.prng.normal(scale=variance ** 0.5, size=100000)
+        self.samples = self.prng.normal(scale=variance**0.5, size=100000)
 
     def test_nanvar_all_finite(self):
         samples = self.samples
         actual_variance = nanops.nanvar(samples)
-        tm.assert_almost_equal(actual_variance, self.variance, check_less_precise=2)
+        tm.assert_almost_equal(actual_variance, self.variance, rtol=1e-2)
 
     def test_nanvar_nans(self):
         samples = np.nan * np.ones(2 * self.samples.shape[0])
         samples[::2] = self.samples
 
         actual_variance = nanops.nanvar(samples, skipna=True)
-        tm.assert_almost_equal(actual_variance, self.variance, check_less_precise=2)
+        tm.assert_almost_equal(actual_variance, self.variance, rtol=1e-2)
 
         actual_variance = nanops.nanvar(samples, skipna=False)
-        tm.assert_almost_equal(actual_variance, np.nan, check_less_precise=2)
+        tm.assert_almost_equal(actual_variance, np.nan, rtol=1e-2)
 
     def test_nanstd_nans(self):
         samples = np.nan * np.ones(2 * self.samples.shape[0])
         samples[::2] = self.samples
 
         actual_std = nanops.nanstd(samples, skipna=True)
-        tm.assert_almost_equal(actual_std, self.variance ** 0.5, check_less_precise=2)
+        tm.assert_almost_equal(actual_std, self.variance**0.5, rtol=1e-2)
 
         actual_std = nanops.nanvar(samples, skipna=False)
-        tm.assert_almost_equal(actual_std, np.nan, check_less_precise=2)
+        tm.assert_almost_equal(actual_std, np.nan, rtol=1e-2)
 
     def test_nanvar_axis(self):
         # Generate some sample data.
@@ -814,7 +823,7 @@ class TestNanvarFixedValues:
 
         actual_variance = nanops.nanvar(samples, axis=1)
         tm.assert_almost_equal(
-            actual_variance, np.array([self.variance, 1.0 / 12]), check_less_precise=2
+            actual_variance, np.array([self.variance, 1.0 / 12]), rtol=1e-2
         )
 
     def test_nanvar_ddof(self):
@@ -828,17 +837,17 @@ class TestNanvarFixedValues:
 
         # The unbiased estimate.
         var = 1.0 / 12
-        tm.assert_almost_equal(variance_1, var, check_less_precise=2)
+        tm.assert_almost_equal(variance_1, var, rtol=1e-2)
 
         # The underestimated variance.
-        tm.assert_almost_equal(variance_0, (n - 1.0) / n * var, check_less_precise=2)
+        tm.assert_almost_equal(variance_0, (n - 1.0) / n * var, rtol=1e-2)
 
         # The overestimated variance.
-        tm.assert_almost_equal(
-            variance_2, (n - 1.0) / (n - 2.0) * var, check_less_precise=2
-        )
+        tm.assert_almost_equal(variance_2, (n - 1.0) / (n - 2.0) * var, rtol=1e-2)
 
-    def test_ground_truth(self):
+    @pytest.mark.parametrize("axis", range(2))
+    @pytest.mark.parametrize("ddof", range(3))
+    def test_ground_truth(self, axis, ddof):
         # Test against values that were precomputed with Numpy.
         samples = np.empty((4, 4))
         samples[:3, :3] = np.array(
@@ -867,26 +876,22 @@ class TestNanvarFixedValues:
         )
 
         # Test nanvar.
-        for axis in range(2):
-            for ddof in range(3):
-                var = nanops.nanvar(samples, skipna=True, axis=axis, ddof=ddof)
-                tm.assert_almost_equal(var[:3], variance[axis, ddof])
-                assert np.isnan(var[3])
+        var = nanops.nanvar(samples, skipna=True, axis=axis, ddof=ddof)
+        tm.assert_almost_equal(var[:3], variance[axis, ddof])
+        assert np.isnan(var[3])
 
         # Test nanstd.
-        for axis in range(2):
-            for ddof in range(3):
-                std = nanops.nanstd(samples, skipna=True, axis=axis, ddof=ddof)
-                tm.assert_almost_equal(std[:3], variance[axis, ddof] ** 0.5)
-                assert np.isnan(std[3])
+        std = nanops.nanstd(samples, skipna=True, axis=axis, ddof=ddof)
+        tm.assert_almost_equal(std[:3], variance[axis, ddof] ** 0.5)
+        assert np.isnan(std[3])
 
-    def test_nanstd_roundoff(self):
+    @pytest.mark.parametrize("ddof", range(3))
+    def test_nanstd_roundoff(self, ddof):
         # Regression test for GH 10242 (test data taken from GH 10489). Ensure
         # that variance is stable.
         data = Series(766897346 * np.ones(10))
-        for ddof in range(3):
-            result = data.std(ddof=ddof)
-            assert result == 0.0
+        result = data.std(ddof=ddof)
+        assert result == 0.0
 
     @property
     def prng(self):
@@ -897,7 +902,7 @@ class TestNanskewFixedValues:
 
     # xref GH 11974
 
-    def setup_method(self, method):
+    def setup_method(self):
         # Test data + skewness value (computed with scipy.stats.skew)
         self.samples = np.sin(np.linspace(0, 1, 200))
         self.actual_skew = -0.1875895205961754
@@ -946,17 +951,17 @@ class TestNankurtFixedValues:
 
     # xref GH 11974
 
-    def setup_method(self, method):
+    def setup_method(self):
         # Test data + kurtosis value (computed with scipy.stats.kurtosis)
         self.samples = np.sin(np.linspace(0, 1, 200))
         self.actual_kurt = -1.2058303433799713
 
-    def test_constant_series(self):
+    @pytest.mark.parametrize("val", [3075.2, 3075.3, 3075.5])
+    def test_constant_series(self, val):
         # xref GH 11974
-        for val in [3075.2, 3075.3, 3075.5]:
-            data = val * np.ones(300)
-            kurt = nanops.nankurt(data)
-            assert kurt == 0.0
+        data = val * np.ones(300)
+        kurt = nanops.nankurt(data)
+        assert kurt == 0.0
 
     def test_all_finite(self):
         alpha, beta = 0.3, 0.1
@@ -992,12 +997,10 @@ class TestNankurtFixedValues:
 
 
 class TestDatetime64NaNOps:
-    @pytest.mark.parametrize("tz", [None, "UTC"])
-    @pytest.mark.xfail(reason="disabled")
     # Enabling mean changes the behavior of DataFrame.mean
     # See https://github.com/pandas-dev/pandas/issues/24752
-    def test_nanmean(self, tz):
-        dti = pd.date_range("2016-01-01", periods=3, tz=tz)
+    def test_nanmean(self):
+        dti = pd.date_range("2016-01-01", periods=3)
         expected = dti[1]
 
         for obj in [dti, DatetimeArray(dti), Series(dti)]:
@@ -1010,18 +1013,34 @@ class TestDatetime64NaNOps:
             result = nanops.nanmean(obj)
             assert result == expected
 
+    @pytest.mark.parametrize("dtype", ["M8[ns]", "m8[ns]"])
+    def test_nanmean_skipna_false(self, dtype):
+        arr = np.arange(12).astype(np.int64).view(dtype).reshape(4, 3)
+
+        arr[-1, -1] = "NaT"
+
+        result = nanops.nanmean(arr, skipna=False)
+        assert np.isnat(result)
+        assert result.dtype == dtype
+
+        result = nanops.nanmean(arr, axis=0, skipna=False)
+        expected = np.array([4, 5, "NaT"], dtype=arr.dtype)
+        tm.assert_numpy_array_equal(result, expected)
+
+        result = nanops.nanmean(arr, axis=1, skipna=False)
+        expected = np.array([arr[0, 1], arr[1, 1], arr[2, 1], arr[-1, -1]])
+        tm.assert_numpy_array_equal(result, expected)
+
 
 def test_use_bottleneck():
 
     if nanops._BOTTLENECK_INSTALLED:
 
-        pd.set_option("use_bottleneck", True)
-        assert pd.get_option("use_bottleneck")
+        with pd.option_context("use_bottleneck", True):
+            assert pd.get_option("use_bottleneck")
 
-        pd.set_option("use_bottleneck", False)
-        assert not pd.get_option("use_bottleneck")
-
-        pd.set_option("use_bottleneck", use_bn)
+        with pd.option_context("use_bottleneck", False):
+            assert not pd.get_option("use_bottleneck")
 
 
 @pytest.mark.parametrize(
@@ -1041,7 +1060,7 @@ def test_use_bottleneck():
 )
 def test_numpy_ops(numpy_op, expected):
     # GH8383
-    result = numpy_op(pd.Series([1, 2, 3, 4]))
+    result = numpy_op(Series([1, 2, 3, 4]))
     assert result == expected
 
 
@@ -1067,8 +1086,59 @@ def test_numpy_ops(numpy_op, expected):
 )
 def test_nanops_independent_of_mask_param(operation):
     # GH22764
-    s = pd.Series([1, 2, np.nan, 3, np.nan, 4])
+    s = Series([1, 2, np.nan, 3, np.nan, 4])
     mask = s.isna()
     median_expected = operation(s)
     median_result = operation(s, mask=mask)
     assert median_expected == median_result
+
+
+@pytest.mark.parametrize("min_count", [-1, 0])
+def test_check_below_min_count__negative_or_zero_min_count(min_count):
+    # GH35227
+    result = nanops.check_below_min_count((21, 37), None, min_count)
+    expected_result = False
+    assert result == expected_result
+
+
+@pytest.mark.parametrize(
+    "mask", [None, np.array([False, False, True]), np.array([True] + 9 * [False])]
+)
+@pytest.mark.parametrize("min_count, expected_result", [(1, False), (101, True)])
+def test_check_below_min_count__positive_min_count(mask, min_count, expected_result):
+    # GH35227
+    shape = (10, 10)
+    result = nanops.check_below_min_count(shape, mask, min_count)
+    assert result == expected_result
+
+
+@td.skip_if_windows
+@td.skip_if_32bit
+@pytest.mark.parametrize("min_count, expected_result", [(1, False), (2812191852, True)])
+def test_check_below_min_count__large_shape(min_count, expected_result):
+    # GH35227 large shape used to show that the issue is fixed
+    shape = (2244367, 1253)
+    result = nanops.check_below_min_count(shape, mask=None, min_count=min_count)
+    assert result == expected_result
+
+
+@pytest.mark.parametrize("func", ["nanmean", "nansum"])
+@pytest.mark.parametrize(
+    "dtype",
+    [
+        np.uint8,
+        np.uint16,
+        np.uint32,
+        np.uint64,
+        np.int8,
+        np.int16,
+        np.int32,
+        np.int64,
+        np.float16,
+        np.float32,
+        np.float64,
+    ],
+)
+def test_check_bottleneck_disallow(dtype, func):
+    # GH 42878 bottleneck sometimes produces unreliable results for mean and sum
+    assert not nanops._bn_ok_dtype(dtype, func)
